@@ -22,7 +22,7 @@ INT_DEFAULTS = dict.fromkeys((
     'min_dh_size', 'min_dsa_size', 'min_rsa_size',
     'sha1_in_certs',
     'ssh_certs',
-), 0)
+), 0) | {'min_ec_size': 256}
 
 
 # For enum values, first value works as default,
